@@ -13,14 +13,14 @@ import pandas as pd
 from pandas import MultiIndex
 from sklearn.preprocessing import label_binarize
 
-from bmomd.nannyml._typing import ModelOutputsType, ProblemType, model_output_column_names
-from bmomd.nannyml.base import AbstractEstimator, _list_missing
-from bmomd.nannyml.calibration import Calibrator, CalibratorFactory, NoopCalibrator, needs_calibration
-from bmomd.nannyml.chunk import Chunk, Chunker
-from bmomd.nannyml.exceptions import InvalidArgumentsException
-from bmomd.nannyml.performance_estimation.confidence_based.metrics import MetricFactory
-from bmomd.nannyml.performance_estimation.confidence_based.results import SUPPORTED_METRIC_VALUES, Result
-from bmomd.nannyml.usage_logging import UsageEvent, log_usage
+from mlopsdna.nannyml._typing import ModelOutputsType, ProblemType, model_output_column_names
+from mlopsdna.nannyml.base import AbstractEstimator, _list_missing
+from mlopsdna.nannyml.calibration import Calibrator, CalibratorFactory, NoopCalibrator, needs_calibration
+from mlopsdna.nannyml.chunk import Chunk, Chunker
+from mlopsdna.nannyml.exceptions import InvalidArgumentsException
+from mlopsdna.nannyml.performance_estimation.confidence_based.metrics import MetricFactory
+from mlopsdna.nannyml.performance_estimation.confidence_based.results import SUPPORTED_METRIC_VALUES, Result
+from mlopsdna.nannyml.usage_logging import UsageEvent, log_usage
 
 
 class CBPE(AbstractEstimator):
