@@ -17,11 +17,11 @@ from sklearn.metrics import (
     mean_squared_log_error,
 )
 
-from bmomd.nannyml._typing import ProblemType
-from bmomd.nannyml.base import _raise_exception_for_negative_values
-from bmomd.nannyml.chunk import Chunk, Chunker
-from bmomd.nannyml.exceptions import InvalidArgumentsException
-from bmomd.nannyml.sampling_error.regression import (
+from mlopsdna.nannyml._typing import ProblemType
+from mlopsdna.nannyml.base import _raise_exception_for_negative_values
+from mlopsdna.nannyml.chunk import Chunk, Chunker
+from mlopsdna.nannyml.exceptions import InvalidArgumentsException
+from mlopsdna.nannyml.sampling_error.regression import (
     mae_sampling_error,
     mae_sampling_error_components,
     mape_sampling_error,
