@@ -8,9 +8,9 @@ from typing import Any, Dict, Optional, Union
 import numpy as np
 import pandas as pd
 
-from bmomd.nannyml._typing import Key, Result
-from bmomd.nannyml.plots import Colors, ensure_numpy, has_non_null_data, is_time_based_x_axis
-from bmomd.nannyml.plots.components import Figure, Hover, render_alert_string, render_period_string, render_x_coordinate
+from mlopsdna.nannyml._typing import Key, Result
+from mlopsdna.nannyml.plots import Colors, ensure_numpy, has_non_null_data, is_time_based_x_axis
+from mlopsdna.nannyml.plots.components import Figure, Hover, render_alert_string, render_period_string, render_x_coordinate
 
 
 def plot_metrics(
