@@ -13,16 +13,16 @@ import pandas as pd
 from rich.console import Console
 from rich.progress import Progress
 
-from bmomd.nannyml._typing import ProblemType
-from bmomd.nannyml.chunk import Chunker
-from bmomd.nannyml.drift.multivariate.data_reconstruction import DataReconstructionDriftCalculator
-from bmomd.nannyml.drift.univariate import UnivariateDriftCalculator
-from bmomd.nannyml.io.base import Writer
-from bmomd.nannyml.io.raw_files_writer import RawFilesWriter
-from bmomd.nannyml.io.store import Store
-from bmomd.nannyml.performance_calculation import PerformanceCalculator
-from bmomd.nannyml.performance_estimation.confidence_based import CBPE
-from bmomd.nannyml.performance_estimation.direct_loss_estimation.dle import DEFAULT_METRICS, DLE
+from mlopsdna.nannyml._typing import ProblemType
+from mlopsdna.nannyml.chunk import Chunker
+from mlopsdna.nannyml.drift.multivariate.data_reconstruction import DataReconstructionDriftCalculator
+from mlopsdna.nannyml.drift.univariate import UnivariateDriftCalculator
+from mlopsdna.nannyml.io.base import Writer
+from mlopsdna.nannyml.io.raw_files_writer import RawFilesWriter
+from mlopsdna.nannyml.io.store import Store
+from mlopsdna.nannyml.performance_calculation import PerformanceCalculator
+from mlopsdna.nannyml.performance_estimation.confidence_based import CBPE
+from mlopsdna.nannyml.performance_estimation.direct_loss_estimation.dle import DEFAULT_METRICS, DLE
 
 _logger = logging.getLogger(__name__)
 
